pub struct DefaultSpatialScale(pub SpatialScale);Expand description
Shadow of bevy::audio::DefaultSpatialScale.
Tuple Fields
0: SpatialScaleTrait Implementations
Sourceimpl Clone for DefaultSpatialScale
impl Clone for DefaultSpatialScale
Sourcefn clone(&self) -> DefaultSpatialScale
fn clone(&self) -> DefaultSpatialScale
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefaultSpatialScale
impl Debug for DefaultSpatialScale
Sourceimpl<'de> Deserialize<'de> for DefaultSpatialScale
impl<'de> Deserialize<'de> for DefaultSpatialScale
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ElicitComplete for DefaultSpatialScale
impl ElicitComplete for DefaultSpatialScale
Sourcefn validate_proofs_non_empty() -> bool
fn validate_proofs_non_empty() -> bool
Runtime check: all three proof methods return non-empty TokenStreams. Read more
Sourcefn kani_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
fn kani_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
Runtime check: does this type’s Kani proof contain
Inner’s Kani proof? Read moreSourcefn verus_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
fn verus_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
Runtime check: does this type’s Verus proof contain
Inner’s Verus proof?Sourcefn creusot_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
fn creusot_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
Runtime check: does this type’s Creusot proof contain
Inner’s Creusot proof?Sourceimpl ElicitIntrospect for DefaultSpatialScale
impl ElicitIntrospect for DefaultSpatialScale
Sourcefn pattern() -> ElicitationPattern
fn pattern() -> ElicitationPattern
What elicitation pattern does this type use? Read more
Sourcefn metadata() -> TypeMetadata
fn metadata() -> TypeMetadata
Get the complete structural metadata for this type. Read more
Sourceimpl ElicitPromptTree for DefaultSpatialScale
impl ElicitPromptTree for DefaultSpatialScale
Sourcefn prompt_tree() -> PromptTree
fn prompt_tree() -> PromptTree
Return the static prompt tree for this type. Read more
Sourcefn assembled_prompts() -> Vec<AssembledPrompt>
fn assembled_prompts() -> Vec<AssembledPrompt>
Return the complete assembled prompts in elicitation order. Read more
Sourceimpl ElicitSpec for DefaultSpatialScale
impl ElicitSpec for DefaultSpatialScale
Sourceimpl Elicitation for DefaultSpatialScale
impl Elicitation for DefaultSpatialScale
Sourceasync fn elicit<C: ElicitCommunicator>(communicator: &C) -> ElicitResult<Self>
async fn elicit<C: ElicitCommunicator>(communicator: &C) -> ElicitResult<Self>
Elicit a value of this type from the user via style-aware client. Read more
Sourcefn kani_proof() -> TokenStream
fn kani_proof() -> TokenStream
Generate a Kani symbolic execution proof harness for this type. Read more
Sourcefn verus_proof() -> TokenStream
fn verus_proof() -> TokenStream
Returns a
proc_macro2::TokenStream containing a Verus-verified function
with requires/ensures specifications for this type’s invariants. Read moreSourcefn creusot_proof() -> TokenStream
fn creusot_proof() -> TokenStream
Returns a
proc_macro2::TokenStream containing Creusot contract functions
with #[requires]/#[ensures]/#[trusted] attributes for this type’s invariants. Read moreSourcefn elicit_checked(
peer: Peer<RoleServer>,
) -> impl Future<Output = Result<Self, ElicitError>> + Send
fn elicit_checked( peer: Peer<RoleServer>, ) -> impl Future<Output = Result<Self, ElicitError>> + Send
Server-side elicitation via MCP peer. Read more
Sourcefn with_style(style: Self::Style) -> ElicitBuilder<Self>
fn with_style(style: Self::Style) -> ElicitBuilder<Self>
Create a builder for one-off style override. Read more
Sourcefn elicit_proven<C>(
communicator: &C,
) -> impl Future<Output = Result<(Self, Established<Is<Self>>), ElicitError>> + Sendwhere
C: ElicitCommunicator,
fn elicit_proven<C>(
communicator: &C,
) -> impl Future<Output = Result<(Self, Established<Is<Self>>), ElicitError>> + Sendwhere
C: ElicitCommunicator,
Elicit a value with proof it inhabits type Self. Read more
Sourcefn prusti_proof() -> TokenStream
fn prusti_proof() -> TokenStream
Returns a
proc_macro2::TokenStream containing Prusti contract functions
with #[requires]/#[ensures] attributes for this type’s invariants. Read moreSourceimpl From<DefaultSpatialScale> for DefaultSpatialScale
impl From<DefaultSpatialScale> for DefaultSpatialScale
Sourcefn from(v: DefaultSpatialScale) -> Self
fn from(v: DefaultSpatialScale) -> Self
Converts to this type from the input type.
Sourceimpl From<DefaultSpatialScale> for DefaultSpatialScale
impl From<DefaultSpatialScale> for DefaultSpatialScale
Sourcefn from(v: DefaultSpatialScale) -> Self
fn from(v: DefaultSpatialScale) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for DefaultSpatialScale
impl JsonSchema for DefaultSpatialScale
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Prompt for DefaultSpatialScale
impl Prompt for DefaultSpatialScale
Sourceimpl Serialize for DefaultSpatialScale
impl Serialize for DefaultSpatialScale
Sourceimpl ToCodeLiteral for DefaultSpatialScale
impl ToCodeLiteral for DefaultSpatialScale
Sourcefn to_code_literal(&self) -> TokenStream
fn to_code_literal(&self) -> TokenStream
Return a
TokenStream containing a single Rust expression whose
evaluation produces a value equal to self.Sourcefn type_tokens() -> TokenStreamwhere
Self: Sized,
fn type_tokens() -> TokenStreamwhere
Self: Sized,
Token stream for the concrete type name (used to annotate
None::<T>). Read moreAuto Trait Implementations
impl Freeze for DefaultSpatialScale
impl RefUnwindSafe for DefaultSpatialScale
impl Send for DefaultSpatialScale
impl Sync for DefaultSpatialScale
impl Unpin for DefaultSpatialScale
impl UnsafeUnpin for DefaultSpatialScale
impl UnwindSafe for DefaultSpatialScale