pub struct Color(pub Arc<Color>);Expand description
Elicitation-enabled wrapper around bevy::color::Color.
This newtype uses Arc internally to ensure Clone is always available,
providing transparent access via Deref and DerefMut.
Tuple Fields
0: Arc<Color>Implementations
Sourceimpl Color
impl Color
Sourcepub fn to_linear(&self) -> LinearRgba
pub fn to_linear(&self) -> LinearRgba
Converts to linear RGB color space.
Sourcepub fn color_alpha(&self) -> f32
pub fn color_alpha(&self) -> f32
Alpha component.
Sourcepub fn color_with_alpha(&self, alpha: f32) -> Color
pub fn color_with_alpha(&self, alpha: f32) -> Color
Returns a copy with alpha set to alpha.
Sourcepub fn color_is_fully_transparent(&self) -> bool
pub fn color_is_fully_transparent(&self) -> bool
Returns true if the color is fully transparent.
Sourcepub fn color_is_fully_opaque(&self) -> bool
pub fn color_is_fully_opaque(&self) -> bool
Returns true if the color is fully opaque.
Sourcepub fn linear_slow_transition(&self, end: Color, f: f32) -> Color
pub fn linear_slow_transition(&self, end: Color, f: f32) -> Color
Linearly interpolates between self and end in linear RGB space.
Sourcepub fn variant_name(&self) -> &'static str
pub fn variant_name(&self) -> &'static str
Variant name, e.g. "Srgba", "LinearRgba".
Sourcepub fn is_linear_rgba(&self) -> bool
pub fn is_linear_rgba(&self) -> bool
Returns true if this color is stored in the LinearRgba variant.
Sourcepub fn srgb(&self, r: f32, g: f32, b: f32) -> Color
pub fn srgb(&self, r: f32, g: f32, b: f32) -> Color
Constructs from sRGB r, g, b with alpha = 1.0 (ignores self).
Sourcepub fn srgb_from_hex(&self, hex: &str) -> Option<Color>
pub fn srgb_from_hex(&self, hex: &str) -> Option<Color>
Constructs from a CSS hex string (ignores self).
Sourceimpl Color
impl Color
Sourcepub fn to_srgba_tool_tool_attr() -> Tool
pub fn to_srgba_tool_tool_attr() -> Tool
Generated tool metadata function for to_srgba_tool
Sourcepub fn to_srgba_tool(&self) -> Result<Json<Srgba>, ErrorData>
pub fn to_srgba_tool(&self) -> Result<Json<Srgba>, ErrorData>
to_srgba MCP tool wrapper method.
Sourcepub fn to_linear_tool_tool_attr() -> Tool
pub fn to_linear_tool_tool_attr() -> Tool
Generated tool metadata function for to_linear_tool
Sourcepub fn to_linear_tool(&self) -> Result<Json<LinearRgba>, ErrorData>
pub fn to_linear_tool(&self) -> Result<Json<LinearRgba>, ErrorData>
to_linear MCP tool wrapper method.
Sourcepub fn to_hsla_tool_tool_attr() -> Tool
pub fn to_hsla_tool_tool_attr() -> Tool
Generated tool metadata function for to_hsla_tool
Sourcepub fn to_oklaba_tool_tool_attr() -> Tool
pub fn to_oklaba_tool_tool_attr() -> Tool
Generated tool metadata function for to_oklaba_tool
Sourcepub fn to_oklaba_tool(&self) -> Result<Json<Oklaba>, ErrorData>
pub fn to_oklaba_tool(&self) -> Result<Json<Oklaba>, ErrorData>
to_oklaba MCP tool wrapper method.
Sourcepub fn color_alpha_tool_tool_attr() -> Tool
pub fn color_alpha_tool_tool_attr() -> Tool
Generated tool metadata function for color_alpha_tool
Sourcepub fn color_alpha_tool(&self) -> Result<Json<f32>, ErrorData>
pub fn color_alpha_tool(&self) -> Result<Json<f32>, ErrorData>
color_alpha MCP tool wrapper method.
Sourcepub fn color_with_alpha_tool_tool_attr() -> Tool
pub fn color_with_alpha_tool_tool_attr() -> Tool
Generated tool metadata function for color_with_alpha_tool
Sourcepub fn color_with_alpha_tool(
&self,
params: Parameters<ColorWithAlphaParams>,
) -> Result<Json<Color>, ErrorData>
pub fn color_with_alpha_tool( &self, params: Parameters<ColorWithAlphaParams>, ) -> Result<Json<Color>, ErrorData>
color_with_alpha MCP tool wrapper method.
Sourcepub fn color_is_fully_transparent_tool_tool_attr() -> Tool
pub fn color_is_fully_transparent_tool_tool_attr() -> Tool
Generated tool metadata function for color_is_fully_transparent_tool
Sourcepub fn color_is_fully_transparent_tool(&self) -> Result<Json<bool>, ErrorData>
pub fn color_is_fully_transparent_tool(&self) -> Result<Json<bool>, ErrorData>
color_is_fully_transparent MCP tool wrapper method.
Sourcepub fn color_is_fully_opaque_tool_tool_attr() -> Tool
pub fn color_is_fully_opaque_tool_tool_attr() -> Tool
Generated tool metadata function for color_is_fully_opaque_tool
Sourcepub fn color_is_fully_opaque_tool(&self) -> Result<Json<bool>, ErrorData>
pub fn color_is_fully_opaque_tool(&self) -> Result<Json<bool>, ErrorData>
color_is_fully_opaque MCP tool wrapper method.
Sourcepub fn linear_slow_transition_tool_tool_attr() -> Tool
pub fn linear_slow_transition_tool_tool_attr() -> Tool
Generated tool metadata function for linear_slow_transition_tool
Sourcepub fn linear_slow_transition_tool(
&self,
params: Parameters<LinearSlowTransitionParams>,
) -> Result<Json<Color>, ErrorData>
pub fn linear_slow_transition_tool( &self, params: Parameters<LinearSlowTransitionParams>, ) -> Result<Json<Color>, ErrorData>
linear_slow_transition MCP tool wrapper method.
Sourcepub fn variant_name_tool_tool_attr() -> Tool
pub fn variant_name_tool_tool_attr() -> Tool
Generated tool metadata function for variant_name_tool
Sourcepub fn variant_name_tool(&self) -> Result<Json<&'static str>, ErrorData>
pub fn variant_name_tool(&self) -> Result<Json<&'static str>, ErrorData>
variant_name MCP tool wrapper method.
Sourcepub fn is_srgba_tool_tool_attr() -> Tool
pub fn is_srgba_tool_tool_attr() -> Tool
Generated tool metadata function for is_srgba_tool
Sourcepub fn is_linear_rgba_tool_tool_attr() -> Tool
pub fn is_linear_rgba_tool_tool_attr() -> Tool
Generated tool metadata function for is_linear_rgba_tool
Sourcepub fn is_linear_rgba_tool(&self) -> Result<Json<bool>, ErrorData>
pub fn is_linear_rgba_tool(&self) -> Result<Json<bool>, ErrorData>
is_linear_rgba MCP tool wrapper method.
Sourcepub fn is_hsla_tool_tool_attr() -> Tool
pub fn is_hsla_tool_tool_attr() -> Tool
Generated tool metadata function for is_hsla_tool
Sourcepub fn white_tool_tool_attr() -> Tool
pub fn white_tool_tool_attr() -> Tool
Generated tool metadata function for white_tool
Sourcepub fn black_tool_tool_attr() -> Tool
pub fn black_tool_tool_attr() -> Tool
Generated tool metadata function for black_tool
Sourcepub fn none_tool_tool_attr() -> Tool
pub fn none_tool_tool_attr() -> Tool
Generated tool metadata function for none_tool
Sourcepub fn srgb_tool_tool_attr() -> Tool
pub fn srgb_tool_tool_attr() -> Tool
Generated tool metadata function for srgb_tool
Sourcepub fn srgb_tool(
&self,
params: Parameters<SrgbParams>,
) -> Result<Json<Color>, ErrorData>
pub fn srgb_tool( &self, params: Parameters<SrgbParams>, ) -> Result<Json<Color>, ErrorData>
srgb MCP tool wrapper method.
Sourcepub fn srgb_from_hex_tool_tool_attr() -> Tool
pub fn srgb_from_hex_tool_tool_attr() -> Tool
Generated tool metadata function for srgb_from_hex_tool
Sourcepub fn srgb_from_hex_tool(
&self,
params: Parameters<SrgbFromHexParams>,
) -> Result<Json<Option<Color>>, ErrorData>
pub fn srgb_from_hex_tool( &self, params: Parameters<SrgbFromHexParams>, ) -> Result<Json<Option<Color>>, ErrorData>
srgb_from_hex MCP tool wrapper method.