pub struct AutoFocus;Expand description
Shadow of bevy::input_focus::AutoFocus.
Marker component: when added to an entity, immediately sets that entity as the current input focus via a component hook.