pub struct DirectionalLight(pub Arc<DirectionalLight>);Expand description
Elicitation-enabled wrapper around bevy::light::DirectionalLight.
This newtype uses Arc internally to ensure Clone is always available,
providing transparent access via Deref and DerefMut.
Tuple Fields
0: Arc<DirectionalLight>Implementations
Sourceimpl DirectionalLight
impl DirectionalLight
Sourcepub fn directional_light_color(&self) -> Color
pub fn directional_light_color(&self) -> Color
Returns the light color.
Sourcepub fn illuminance(&self) -> f32
pub fn illuminance(&self) -> f32
Returns the illuminance in lux.
Sourcepub fn directional_light_shadows_enabled(&self) -> bool
pub fn directional_light_shadows_enabled(&self) -> bool
Returns true if shadows are enabled.
Sourcepub fn new_directional(&self, illuminance: f32) -> DirectionalLight
pub fn new_directional(&self, illuminance: f32) -> DirectionalLight
Creates a default directional light with the given illuminance.
Sourcepub fn directional_light_with_shadows(&self, enabled: bool) -> DirectionalLight
pub fn directional_light_with_shadows(&self, enabled: bool) -> DirectionalLight
Returns a copy with shadows enabled or disabled.
Sourceimpl DirectionalLight
impl DirectionalLight
Sourcepub fn directional_light_color_tool_tool_attr() -> Tool
pub fn directional_light_color_tool_tool_attr() -> Tool
Generated tool metadata function for directional_light_color_tool
Sourcepub fn directional_light_color_tool(&self) -> Result<Json<Color>, ErrorData>
pub fn directional_light_color_tool(&self) -> Result<Json<Color>, ErrorData>
directional_light_color MCP tool wrapper method.
Sourcepub fn illuminance_tool_tool_attr() -> Tool
pub fn illuminance_tool_tool_attr() -> Tool
Generated tool metadata function for illuminance_tool
Sourcepub fn illuminance_tool(&self) -> Result<Json<f32>, ErrorData>
pub fn illuminance_tool(&self) -> Result<Json<f32>, ErrorData>
illuminance MCP tool wrapper method.
Sourcepub fn directional_light_shadows_enabled_tool_tool_attr() -> Tool
pub fn directional_light_shadows_enabled_tool_tool_attr() -> Tool
Generated tool metadata function for directional_light_shadows_enabled_tool
Sourcepub fn directional_light_shadows_enabled_tool(
&self,
) -> Result<Json<bool>, ErrorData>
pub fn directional_light_shadows_enabled_tool( &self, ) -> Result<Json<bool>, ErrorData>
directional_light_shadows_enabled MCP tool wrapper method.
Sourcepub fn new_directional_tool_tool_attr() -> Tool
pub fn new_directional_tool_tool_attr() -> Tool
Generated tool metadata function for new_directional_tool
Sourcepub fn new_directional_tool(
&self,
params: Parameters<NewDirectionalParams>,
) -> Result<Json<DirectionalLight>, ErrorData>
pub fn new_directional_tool( &self, params: Parameters<NewDirectionalParams>, ) -> Result<Json<DirectionalLight>, ErrorData>
new_directional MCP tool wrapper method.
Sourcepub fn directional_light_with_shadows_tool_tool_attr() -> Tool
pub fn directional_light_with_shadows_tool_tool_attr() -> Tool
Generated tool metadata function for directional_light_with_shadows_tool
Sourcepub fn directional_light_with_shadows_tool(
&self,
params: Parameters<DirectionalLightWithShadowsParams>,
) -> Result<Json<DirectionalLight>, ErrorData>
pub fn directional_light_with_shadows_tool( &self, params: Parameters<DirectionalLightWithShadowsParams>, ) -> Result<Json<DirectionalLight>, ErrorData>
directional_light_with_shadows MCP tool wrapper method.
Methods from Deref<Target = DirectionalLight>
pub const DEFAULT_SHADOW_DEPTH_BIAS: f32 = 0.02
pub const DEFAULT_SHADOW_NORMAL_BIAS: f32 = 1.8