pub struct Circle(pub Arc<Circle>);Expand description
Elicitation-enabled wrapper around bevy::math::primitives::Circle.
This newtype uses Arc internally to ensure Clone is always available,
providing transparent access via Deref and DerefMut.
Tuple Fields
0: Arc<Circle>Implementations
Sourceimpl Circle
impl Circle
Sourcepub fn circle_radius(&self) -> f32
pub fn circle_radius(&self) -> f32
Radius.
Sourcepub fn circle_new(&self, radius: f32) -> Circle
pub fn circle_new(&self, radius: f32) -> Circle
Constructs with the given radius (ignores self).
Sourceimpl Circle
impl Circle
Sourcepub fn circle_radius_tool_tool_attr() -> Tool
pub fn circle_radius_tool_tool_attr() -> Tool
Generated tool metadata function for circle_radius_tool
Sourcepub fn circle_radius_tool(&self) -> Result<Json<f32>, ErrorData>
pub fn circle_radius_tool(&self) -> Result<Json<f32>, ErrorData>
circle_radius MCP tool wrapper method.
Sourcepub fn diameter_tool_tool_attr() -> Tool
pub fn diameter_tool_tool_attr() -> Tool
Generated tool metadata function for diameter_tool
Sourcepub fn circle_new_tool_tool_attr() -> Tool
pub fn circle_new_tool_tool_attr() -> Tool
Generated tool metadata function for circle_new_tool
Sourcepub fn circle_new_tool(
&self,
params: Parameters<CircleNewParams>,
) -> Result<Json<Circle>, ErrorData>
pub fn circle_new_tool( &self, params: Parameters<CircleNewParams>, ) -> Result<Json<Circle>, ErrorData>
circle_new MCP tool wrapper method.
Methods from Deref<Target = Circle>
Sourcepub fn closest_point(&self, point: Vec2) -> Vec2
pub fn closest_point(&self, point: Vec2) -> Vec2
Finds the point on the circle that is closest to the given point.
If the point is outside the circle, the returned point will be on the perimeter of the circle. Otherwise, it will be inside the circle and returned as is.