Rectangle

Struct Rectangle 

pub struct Rectangle(pub Arc<Rectangle>);
Elicitation-enabled wrapper around bevy::math::primitives::Rectangle.

This newtype uses Arc internally to ensure Clone is always available, providing transparent access via Deref and DerefMut.

Tuple Fields

0: Arc<Rectangle>

Implementations

Source

impl Rectangle

pub fn rectangle_half_size_x(&self) -> f32

Half-width.

pub fn rectangle_half_size_y(&self) -> f32

Half-height.

pub fn rectangle_new(&self, half_width: f32, half_height: f32) -> Rectangle

Constructs with half-width and half-height (ignores self).

Source

impl Rectangle

pub fn rectangle_half_size_x_tool_tool_attr() -> Tool

Generated tool metadata function for rectangle_half_size_x_tool

pub fn rectangle_half_size_x_tool(&self) -> Result<Json<f32>, ErrorData>

rectangle_half_size_x MCP tool wrapper method.

pub fn rectangle_half_size_y_tool_tool_attr() -> Tool

Generated tool metadata function for rectangle_half_size_y_tool

pub fn rectangle_half_size_y_tool(&self) -> Result<Json<f32>, ErrorData>

rectangle_half_size_y MCP tool wrapper method.

pub fn rectangle_new_tool_tool_attr() -> Tool

Generated tool metadata function for rectangle_new_tool

pub fn rectangle_new_tool( &self, params: Parameters<RectangleNewParams>, ) -> Result<Json<Rectangle>, ErrorData>

rectangle_new MCP tool wrapper method.

Methods from Deref<Target = Rectangle>

pub fn size(&self) -> Vec2

Get the size of the rectangle

pub fn closest_point(&self, point: Vec2) -> Vec2

Finds the point on the rectangle that is closest to the given point.

If the point is outside the rectangle, the returned point will be on the perimeter of the rectangle. Otherwise, it will be inside the rectangle and returned as is.