pub struct SpriteImageMode(pub Arc<SpriteImageMode>);Expand description
Elicitation-enabled wrapper around bevy::sprite::SpriteImageMode.
This newtype uses Arc internally to ensure Clone is always available,
providing transparent access via Deref and DerefMut.
Tuple Fields
0: Arc<SpriteImageMode>Implementations
Sourceimpl SpriteImageMode
impl SpriteImageMode
Sourcepub fn variant_name(&self) -> String
pub fn variant_name(&self) -> String
Returns a string name for this variant.
Sourcepub fn get_scale_mode(&self) -> Option<SpriteScalingMode>
pub fn get_scale_mode(&self) -> Option<SpriteScalingMode>
Returns the scaling mode if this is SpriteImageMode::Scale.
Sourceimpl SpriteImageMode
impl SpriteImageMode
Sourcepub fn variant_name_tool_tool_attr() -> Tool
pub fn variant_name_tool_tool_attr() -> Tool
Generated tool metadata function for variant_name_tool
Sourcepub fn variant_name_tool(&self) -> Result<Json<String>, ErrorData>
pub fn variant_name_tool(&self) -> Result<Json<String>, ErrorData>
variant_name MCP tool wrapper method.
Sourcepub fn get_scale_mode_tool_tool_attr() -> Tool
pub fn get_scale_mode_tool_tool_attr() -> Tool
Generated tool metadata function for get_scale_mode_tool
Sourcepub fn get_scale_mode_tool(
&self,
) -> Result<Json<Option<SpriteScalingMode>>, ErrorData>
pub fn get_scale_mode_tool( &self, ) -> Result<Json<Option<SpriteScalingMode>>, ErrorData>
get_scale_mode MCP tool wrapper method.
Methods from Deref<Target = SpriteImageMode>
Sourcepub fn uses_slices(&self) -> bool
pub fn uses_slices(&self) -> bool
Returns true if this mode uses slices internally (SpriteImageMode::Sliced or SpriteImageMode::Tiled)
Sourcepub fn scale(&self) -> Option<SpriteScalingMode>
pub fn scale(&self) -> Option<SpriteScalingMode>
Returns SpriteScalingMode if scale is presented or Option::None otherwise.