LineBreak

Struct LineBreak 

pub struct LineBreak(pub Arc<LineBreak>);
Elicitation-enabled wrapper around bevy::text::LineBreak.

This newtype uses Arc internally to ensure Clone is always available, providing transparent access via Deref and DerefMut.

Tuple Fields

0: Arc<LineBreak>

Implementations

Source

impl LineBreak

pub fn as_str(&self) -> &'static str

Returns the variant name as a static string.

pub fn is_word(&self) -> bool

Returns true if this is LineBreak::WordBoundary.

pub fn is_char(&self) -> bool

Returns true if this is LineBreak::AnyCharacter.

pub fn is_no_wrap(&self) -> bool

Returns true if this is LineBreak::NoWrap.

Source

impl LineBreak

pub fn as_str_tool_tool_attr() -> Tool

Generated tool metadata function for as_str_tool

pub fn as_str_tool(&self) -> Result<Json<&'static str>, ErrorData>

as_str MCP tool wrapper method.

pub fn is_word_tool_tool_attr() -> Tool

Generated tool metadata function for is_word_tool

pub fn is_word_tool(&self) -> Result<Json<bool>, ErrorData>

is_word MCP tool wrapper method.

pub fn is_char_tool_tool_attr() -> Tool

Generated tool metadata function for is_char_tool

pub fn is_char_tool(&self) -> Result<Json<bool>, ErrorData>

is_char MCP tool wrapper method.

pub fn is_no_wrap_tool_tool_attr() -> Tool

Generated tool metadata function for is_no_wrap_tool

pub fn is_no_wrap_tool(&self) -> Result<Json<bool>, ErrorData>

is_no_wrap MCP tool wrapper method.