pub struct InterpolationColorSpace(pub Arc<InterpolationColorSpace>);Expand description
Elicitation-enabled wrapper around bevy::ui::InterpolationColorSpace.
This newtype uses Arc internally to ensure Clone is always available,
providing transparent access via Deref and DerefMut.
Serialization is forwarded transparently to the inner type.
Tuple Fields
0: Arc<InterpolationColorSpace>Trait Implementations
Sourceimpl AsRef<InterpolationColorSpace> for InterpolationColorSpace
impl AsRef<InterpolationColorSpace> for InterpolationColorSpace
Sourcefn as_ref(&self) -> &InterpolationColorSpace
fn as_ref(&self) -> &InterpolationColorSpace
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for InterpolationColorSpace
impl Clone for InterpolationColorSpace
Sourcefn clone(&self) -> InterpolationColorSpace
fn clone(&self) -> InterpolationColorSpace
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterpolationColorSpace
impl Debug for InterpolationColorSpace
Sourceimpl Deref for InterpolationColorSpace
impl Deref for InterpolationColorSpace
Sourceimpl DerefMut for InterpolationColorSpace
impl DerefMut for InterpolationColorSpace
Sourceimpl<'de> Deserialize<'de> for InterpolationColorSpace
impl<'de> Deserialize<'de> for InterpolationColorSpace
Sourcefn deserialize<D: Deserializer<'de>>(d: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(d: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ElicitComplete for InterpolationColorSpace
impl ElicitComplete for InterpolationColorSpace
Sourcefn validate_proofs_non_empty() -> bool
fn validate_proofs_non_empty() -> bool
Runtime check: all three proof methods return non-empty TokenStreams. Read more
Sourcefn kani_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
fn kani_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
Runtime check: does this type’s Kani proof contain
Inner’s Kani proof? Read moreSourcefn verus_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
fn verus_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
Runtime check: does this type’s Verus proof contain
Inner’s Verus proof?Sourcefn creusot_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
fn creusot_proof_contains<Inner>() -> boolwhere
Inner: Elicitation,
Runtime check: does this type’s Creusot proof contain
Inner’s Creusot proof?Sourceimpl ElicitIntrospect for InterpolationColorSpace
impl ElicitIntrospect for InterpolationColorSpace
Sourcefn pattern() -> ElicitationPattern
fn pattern() -> ElicitationPattern
What elicitation pattern does this type use? Read more
Sourcefn metadata() -> TypeMetadata
fn metadata() -> TypeMetadata
Get the complete structural metadata for this type. Read more
Sourceimpl ElicitPromptTree for InterpolationColorSpace
impl ElicitPromptTree for InterpolationColorSpace
Sourcefn prompt_tree() -> PromptTree
fn prompt_tree() -> PromptTree
Return the static prompt tree for this type. Read more
Sourcefn assembled_prompts() -> Vec<AssembledPrompt>
fn assembled_prompts() -> Vec<AssembledPrompt>
Return the complete assembled prompts in elicitation order. Read more
Sourceimpl ElicitSpec for InterpolationColorSpace
impl ElicitSpec for InterpolationColorSpace
Sourceimpl Elicitation for InterpolationColorSpace
impl Elicitation for InterpolationColorSpace
Sourceasync fn elicit<C: ElicitCommunicator>(communicator: &C) -> ElicitResult<Self>
async fn elicit<C: ElicitCommunicator>(communicator: &C) -> ElicitResult<Self>
Elicit a value of this type from the user via style-aware client. Read more
Sourcefn kani_proof() -> TokenStream
fn kani_proof() -> TokenStream
Generate a Kani symbolic execution proof harness for this type. Read more
Sourcefn verus_proof() -> TokenStream
fn verus_proof() -> TokenStream
Returns a
proc_macro2::TokenStream containing a Verus-verified function
with requires/ensures specifications for this type’s invariants. Read moreSourcefn creusot_proof() -> TokenStream
fn creusot_proof() -> TokenStream
Returns a
proc_macro2::TokenStream containing Creusot contract functions
with #[requires]/#[ensures]/#[trusted] attributes for this type’s invariants. Read moreSourcefn elicit_checked(
peer: Peer<RoleServer>,
) -> impl Future<Output = Result<Self, ElicitError>> + Send
fn elicit_checked( peer: Peer<RoleServer>, ) -> impl Future<Output = Result<Self, ElicitError>> + Send
Server-side elicitation via MCP peer. Read more
Sourcefn with_style(style: Self::Style) -> ElicitBuilder<Self>
fn with_style(style: Self::Style) -> ElicitBuilder<Self>
Create a builder for one-off style override. Read more
Sourcefn elicit_proven<C>(
communicator: &C,
) -> impl Future<Output = Result<(Self, Established<Is<Self>>), ElicitError>> + Sendwhere
C: ElicitCommunicator,
fn elicit_proven<C>(
communicator: &C,
) -> impl Future<Output = Result<(Self, Established<Is<Self>>), ElicitError>> + Sendwhere
C: ElicitCommunicator,
Elicit a value with proof it inhabits type Self. Read more
Sourcefn prusti_proof() -> TokenStream
fn prusti_proof() -> TokenStream
Returns a
proc_macro2::TokenStream containing Prusti contract functions
with #[requires]/#[ensures] attributes for this type’s invariants. Read moreimpl Eq for InterpolationColorSpace
Sourceimpl From<Arc<InterpolationColorSpace>> for InterpolationColorSpace
impl From<Arc<InterpolationColorSpace>> for InterpolationColorSpace
Sourcefn from(arc: Arc<InterpolationColorSpace>) -> Self
fn from(arc: Arc<InterpolationColorSpace>) -> Self
Converts to this type from the input type.
Sourceimpl From<InterpolationColorSpace> for Arc<InterpolationColorSpace>
impl From<InterpolationColorSpace> for Arc<InterpolationColorSpace>
Sourcefn from(wrapper: InterpolationColorSpace) -> Self
fn from(wrapper: InterpolationColorSpace) -> Self
Converts to this type from the input type.
Sourceimpl From<InterpolationColorSpace> for InterpolationColorSpace
impl From<InterpolationColorSpace> for InterpolationColorSpace
Sourcefn from(inner: InterpolationColorSpace) -> Self
fn from(inner: InterpolationColorSpace) -> Self
Converts to this type from the input type.
Sourceimpl From<InterpolationColorSpace> for InterpolationColorSpace
impl From<InterpolationColorSpace> for InterpolationColorSpace
Sourcefn from(v: InterpolationColorSpace) -> Self
fn from(v: InterpolationColorSpace) -> Self
Converts to this type from the input type.
Sourceimpl Hash for InterpolationColorSpace
impl Hash for InterpolationColorSpace
Sourceimpl JsonSchema for InterpolationColorSpace
impl JsonSchema for InterpolationColorSpace
Sourcefn json_schema(_gen: &mut SchemaGenerator) -> Schema
fn json_schema(_gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InterpolationColorSpace
impl PartialEq for InterpolationColorSpace
Sourceimpl Prompt for InterpolationColorSpace
impl Prompt for InterpolationColorSpace
Sourceimpl Serialize for InterpolationColorSpace
impl Serialize for InterpolationColorSpace
Sourceimpl ToCodeLiteral for InterpolationColorSpace
impl ToCodeLiteral for InterpolationColorSpace
Sourcefn to_code_literal(&self) -> TokenStream
fn to_code_literal(&self) -> TokenStream
Return a
TokenStream containing a single Rust expression whose
evaluation produces a value equal to self.Sourcefn type_tokens() -> TokenStreamwhere
Self: Sized,
fn type_tokens() -> TokenStreamwhere
Self: Sized,
Token stream for the concrete type name (used to annotate
None::<T>). Read moreAuto Trait Implementations
impl Freeze for InterpolationColorSpace
impl RefUnwindSafe for InterpolationColorSpace
impl Send for InterpolationColorSpace
impl Sync for InterpolationColorSpace
impl Unpin for InterpolationColorSpace
impl UnsafeUnpin for InterpolationColorSpace
impl UnwindSafe for InterpolationColorSpace