pub struct RegularPolygon(pub Arc<RegularPolygon>);Expand description
Elicitation-enabled wrapper around bevy::math::primitives::RegularPolygon.
This newtype uses Arc internally to ensure Clone is always available,
providing transparent access via Deref and DerefMut.
Tuple Fields
0: Arc<RegularPolygon>Implementations
Sourceimpl RegularPolygon
impl RegularPolygon
Sourcepub fn circumradius(&self) -> f32
pub fn circumradius(&self) -> f32
Circumradius (radius of circumscribed circle).
Sourcepub fn regular_polygon_new(
&self,
sides: u32,
circumradius: f32,
) -> RegularPolygon
pub fn regular_polygon_new( &self, sides: u32, circumradius: f32, ) -> RegularPolygon
Constructs from sides and circumradius (ignores self).
Sourceimpl RegularPolygon
impl RegularPolygon
Sourcepub fn sides_tool_tool_attr() -> Tool
pub fn sides_tool_tool_attr() -> Tool
Generated tool metadata function for sides_tool
Sourcepub fn circumradius_tool_tool_attr() -> Tool
pub fn circumradius_tool_tool_attr() -> Tool
Generated tool metadata function for circumradius_tool
Sourcepub fn circumradius_tool(&self) -> Result<Json<f32>, ErrorData>
pub fn circumradius_tool(&self) -> Result<Json<f32>, ErrorData>
circumradius MCP tool wrapper method.
Sourcepub fn regular_polygon_new_tool_tool_attr() -> Tool
pub fn regular_polygon_new_tool_tool_attr() -> Tool
Generated tool metadata function for regular_polygon_new_tool
Sourcepub fn regular_polygon_new_tool(
&self,
params: Parameters<RegularPolygonNewParams>,
) -> Result<Json<RegularPolygon>, ErrorData>
pub fn regular_polygon_new_tool( &self, params: Parameters<RegularPolygonNewParams>, ) -> Result<Json<RegularPolygon>, ErrorData>
regular_polygon_new MCP tool wrapper method.
Methods from Deref<Target = RegularPolygon>
Sourcepub fn circumradius(&self) -> f32
pub fn circumradius(&self) -> f32
Get the radius of the circumcircle on which all vertices of the regular polygon lie
Sourcepub fn inradius(&self) -> f32
pub fn inradius(&self) -> f32
Get the inradius or apothem of the regular polygon. This is the radius of the largest circle that can be drawn within the polygon
Sourcepub fn side_length(&self) -> f32
pub fn side_length(&self) -> f32
Get the length of one side of the regular polygon
Sourcepub fn internal_angle_degrees(&self) -> f32
pub fn internal_angle_degrees(&self) -> f32
Get the internal angle of the regular polygon in degrees.
This is the angle formed by two adjacent sides with points within the angle being in the interior of the polygon
Sourcepub fn internal_angle_radians(&self) -> f32
pub fn internal_angle_radians(&self) -> f32
Get the internal angle of the regular polygon in radians.
This is the angle formed by two adjacent sides with points within the angle being in the interior of the polygon
Sourcepub fn external_angle_degrees(&self) -> f32
pub fn external_angle_degrees(&self) -> f32
Get the external angle of the regular polygon in degrees.
This is the angle formed by two adjacent sides with points within the angle being in the exterior of the polygon
Sourcepub fn external_angle_radians(&self) -> f32
pub fn external_angle_radians(&self) -> f32
Get the external angle of the regular polygon in radians.
This is the angle formed by two adjacent sides with points within the angle being in the exterior of the polygon